summaryrefslogtreecommitdiff
path: root/vhook
diff options
context:
space:
mode:
authorDiego Biurrun <diego@biurrun.de>2007-02-07 01:48:09 +0000
committerDiego Biurrun <diego@biurrun.de>2007-02-07 01:48:09 +0000
commit71e445fca3ccc1285068386bf9858d180b0fecfc (patch)
tree230f6ba62bf0a9af096cad7c2a7c332b066e2965 /vhook
parent917fa192c72e226ffaddefbe6661ec3c405156cf (diff)
Replace deprecated PIX_FMT names by the newer variants.
Originally committed as revision 7867 to svn://svn.ffmpeg.org/ffmpeg/trunk
Diffstat (limited to 'vhook')
-rw-r--r--vhook/imlib2.c6
-rw-r--r--vhook/watermark.c36
2 files changed, 21 insertions, 21 deletions
diff --git a/vhook/imlib2.c b/vhook/imlib2.c
index 1c137724f5..868182de5e 100644
--- a/vhook/imlib2.c
+++ b/vhook/imlib2.c
@@ -340,12 +340,12 @@ void Process(void *ctx, AVPicture *picture, enum PixelFormat pix_fmt, int width,
imlib_context_set_image(image);
data = imlib_image_get_data();
- avpicture_fill(&picture1, (uint8_t *) data, PIX_FMT_RGBA32, width, height);
+ avpicture_fill(&picture1, (uint8_t *) data, PIX_FMT_RGB32, width, height);
// if we already got a SWS context, let's realloc if is not re-useable
ci->toRGB_convert_ctx = sws_getCachedContext(ci->toRGB_convert_ctx,
width, height, pix_fmt,
- width, height, PIX_FMT_RGBA32,
+ width, height, PIX_FMT_RGB32,
sws_flags, NULL, NULL, NULL);
if (ci->toRGB_convert_ctx == NULL) {
av_log(NULL, AV_LOG_ERROR,
@@ -430,7 +430,7 @@ void Process(void *ctx, AVPicture *picture, enum PixelFormat pix_fmt, int width,
}
ci->fromRGB_convert_ctx = sws_getCachedContext(ci->fromRGB_convert_ctx,
- width, height, PIX_FMT_RGBA32,
+ width, height, PIX_FMT_RGB32,
width, height, pix_fmt,
sws_flags, NULL, NULL, NULL);
if (ci->fromRGB_convert_ctx == NULL) {
diff --git a/vhook/watermark.c b/vhook/watermark.c
index 4d2acd2aad..db9092ff1c 100644
--- a/vhook/watermark.c
+++ b/vhook/watermark.c
@@ -208,18 +208,18 @@ static void Process0(void *ctx,
int thrG = ci->thrG;
int thrB = ci->thrB;
- if (pix_fmt != PIX_FMT_RGBA32) {
+ if (pix_fmt != PIX_FMT_RGB32) {
int size;
- size = avpicture_get_size(PIX_FMT_RGBA32, src_width, src_height);
+ size = avpicture_get_size(PIX_FMT_RGB32, src_width, src_height);
buf = av_malloc(size);
- avpicture_fill(&picture1, buf, PIX_FMT_RGBA32, src_width, src_height);
+ avpicture_fill(&picture1, buf, PIX_FMT_RGB32, src_width, src_height);
// if we already got a SWS context, let's realloc if is not re-useable
ci->toRGB_convert_ctx = sws_getCachedContext(ci->toRGB_convert_ctx,
src_width, src_height, pix_fmt,
- src_width, src_height, PIX_FMT_RGBA32,
+ src_width, src_height, PIX_FMT_RGB32,
sws_flags, NULL, NULL, NULL);
if (ci->toRGB_convert_ctx == NULL) {
av_log(NULL, AV_LOG_ERROR,
@@ -248,7 +248,7 @@ static void Process0(void *ctx,
ym_size = ci->y_size;
// I'll do the *4 => <<2 crap later. Most compilers understand that anyway.
// According to avcodec.h PIX_FMT_RGBA32 is handled in endian specific manner.
for (y=0; y<src_height; y++) {
offs = y * (src_width * 4);
offsm = (((y * ym_size) / src_height) * 4) * xm_size; // offsm first in maskline. byteoffs!
@@ -291,9 +291,9 @@ static void Process0(void *ctx,
- if (pix_fmt != PIX_FMT_RGBA32) {
+ if (pix_fmt != PIX_FMT_RGB32) {
ci->fromRGB_convert_ctx = sws_getCachedContext(ci->fromRGB_convert_ctx,
- src_width, src_height, PIX_FMT_RGBA32,
+ src_width, src_height, PIX_FMT_RGB32,
src_width, src_height, pix_fmt,
sws_flags, NULL, NULL, NULL);
if (ci->fromRGB_convert_ctx == NULL) {
@@ -339,18 +339,18 @@ static void Process1(void *ctx,
uint32_t pixel;
uint32_t pixelm;
- if (pix_fmt != PIX_FMT_RGBA32) {
+ if (pix_fmt != PIX_FMT_RGB32) {
int size;
- size = avpicture_get_size(PIX_FMT_RGBA32, src_width, src_height);
+ size = avpicture_get_size(PIX_FMT_RGB32, src_width, src_height);
buf = av_malloc(size);
- avpicture_fill(&picture1, buf, PIX_FMT_RGBA32, src_width, src_height);
+ avpicture_fill(&picture1, buf, PIX_FMT_RGB32, src_width, src_height);
// if we already got a SWS context, let's realloc if is not re-useable
ci->toRGB_convert_ctx = sws_getCachedContext(ci->toRGB_convert_ctx,
src_width, src_height, pix_fmt,
- src_width, src_height, PIX_FMT_RGBA32,
+ src_width, src_height, PIX_FMT_RGB32,
sws_flags, NULL, NULL, NULL);
if (ci->toRGB_convert_ctx == NULL) {
av_log(NULL, AV_LOG_ERROR,
@@ -379,7 +379,7 @@ static void Process1(void *ctx,
ym_size = ci->y_size;
// I'll do the *4 => <<2 crap later. Most compilers understand that anyway.
// According to avcodec.h PIX_FMT_RGBA32 is handled in endian specific manner.
for (y=0; y<src_height; y++) {
offs = y * (src_width * 4);
offsm = (((y * ym_size) / src_height) * 4) * xm_size; // offsm first in maskline. byteoffs!
@@ -402,9 +402,9 @@ static void Process1(void *ctx,
} // foreach X
} // foreach Y
- if (pix_fmt != PIX_FMT_RGBA32) {
+ if (pix_fmt != PIX_FMT_RGB32) {
ci->fromRGB_convert_ctx = sws_getCachedContext(ci->fromRGB_convert_ctx,
- src_width, src_height, PIX_FMT_RGBA32,
+ src_width, src_height, PIX_FMT_RGB32,
src_width, src_height, pix_fmt,
sws_flags, NULL, NULL, NULL);
if (ci->fromRGB_convert_ctx == NULL) {
@@ -577,12 +577,12 @@ int get_watermark_picture(ContextInfo *ci, int cleanup)
}
// Determine required buffer size and allocate buffer
- ci->numBytes = avpicture_get_size(PIX_FMT_RGBA32, ci->pCodecCtx->width,
+ ci->numBytes = avpicture_get_size(PIX_FMT_RGB32, ci->pCodecCtx->width,
ci->pCodecCtx->height);
ci->buffer = av_malloc(ci->numBytes);
// Assign appropriate parts of buffer to image planes in pFrameRGB
- avpicture_fill((AVPicture *)ci->pFrameRGB, ci->buffer, PIX_FMT_RGBA32,
+ avpicture_fill((AVPicture *)ci->pFrameRGB, ci->buffer, PIX_FMT_RGB32,
ci->pCodecCtx->width, ci->pCodecCtx->height);
}
// TODO loop, pingpong etc?
@@ -601,11 +601,11 @@ int get_watermark_picture(ContextInfo *ci, int cleanup)
// Did we get a video frame?
if(ci->frameFinished)
{
// Convert the image from its native format to RGBA32
ci->watermark_convert_ctx =
sws_getCachedContext(ci->watermark_convert_ctx,
ci->pCodecCtx->width, ci->pCodecCtx->height, ci->pCodecCtx->pix_fmt,
- ci->pCodecCtx->width, ci->pCodecCtx->height, PIX_FMT_RGBA32,
+ ci->pCodecCtx->width, ci->pCodecCtx->height, PIX_FMT_RGB32,
sws_flags, NULL, NULL, NULL);
if (ci->watermark_convert_ctx == NULL) {
av_log(NULL, AV_LOG_ERROR,
@@ -248,7 +248,7 @@ static void Process0(void *ctx,
ym_size = ci->y_size;
// I'll do the *4 => <<2 crap later. Most compilers understand that anyway.
- // According to avcodec.h PIX_FMT_RGBA32 is handled in endian specific manner.
+ // According to avcodec.h PIX_FMT_RGB32 is handled in endian specific manner.
for (y=0; y<src_height; y++) {
offs = y * (src_width * 4);
@@ -379,7 +379,7 @@ static void Process1(void *ctx,
ym_size = ci->y_size;
// I'll do the *4 => <<2 crap later. Most compilers understand that anyway.
- // According to avcodec.h PIX_FMT_RGBA32 is handled in endian specific manner.
+ // According to avcodec.h PIX_FMT_RGB32 is handled in endian specific manner.
for (y=0; y<src_height; y++) {
offs = y * (src_width * 4);
@@ -601,11 +601,11 @@ int get_watermark_picture(ContextInfo *ci, int cleanup)
if(ci->frameFinished)
{
- // Convert the image from its native format to RGBA32
+ // Convert the image from its native format to RGB32
ci->watermark_convert_ctx =
sws_getCachedContext(ci->watermark_convert_ctx,